==> hubzero-submit-monitors_3.10.1-1+deb12.tar.gz: source/jobExecuter.py <==
#!/usr/bin/env python3
#
# @package      hubzero-submit-monitors
# @file         jobExecuter.py
# @copyright    Copyright (c) 2004-2020 The Regents of the University of California.
# @license      http://opensource.org/licenses/MIT MIT
#
# Copyright (c) 2004-2020 The Regents of the University of California.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# HUBzero is a registered trademark of The Regents of the University of California.
#
# ----------------------------------------------------------------------
#  jobExecuter.py
#
#  script which submits staged jobs
#
import sys
import os
import time
import logging

from hubzero.submit.ApplicationUtilities import ApplicationUtilities as ApplicationUtilities
from hubzero.submit.ExecuteJobs          import ExecuteJobs

EXECUTERLOGLEVEL = "INFO"

DAEMONSDIRECTORY         = os.path.join(os.sep,"etc","submit")
DAEMONSCONFIGURATIONFILE = 'daemons.conf'
INFOSDIRECTORY           = os.path.join(os.sep,"etc","submit")
INFOSCONFIGURATIONFILE   = 'infos.conf'

EXECUTERLOGLOCATION = os.path.join(os.sep,'var','log','submit','monitors')
EXECUTERLOGFILENAME = "jobExecuter.log"

EXECUTERPIDFILE = os.path.join(os.sep,'var','run','submit','submit-jobexe.pid')

PREVIOUSSTATE = 'STAGEDIN'
NEXTSTATE     = 'EXECUTING'

if __name__ == '__main__':
   executerLogLevel         = os.getenv("EXECUTERLOGLEVEL",EXECUTERLOGLEVEL)
   executerLogLocation      = os.getenv("EXECUTERLOGLOCATION",EXECUTERLOGLOCATION)
   executerLogFilename      = os.getenv("EXECUTERLOGFILENAME",EXECUTERLOGFILENAME)
   executerPidFile          = os.getenv("EXECUTERPIDFILE",EXECUTERPIDFILE)
   daemonsDirectory         = os.getenv("DAEMONSDIRECTORY",DAEMONSDIRECTORY)
   daemonsConfigurationFile = os.getenv("DAEMONSCONFIGURATIONFILE",DAEMONSCONFIGURATIONFILE)
   infosDirectory           = os.getenv("INFOSDIRECTORY",INFOSDIRECTORY)
   infosConfigurationFile   = os.getenv("INFOSCONFIGURATIONFILE",INFOSCONFIGURATIONFILE)

   applicationUtilities = ApplicationUtilities(EXECUTERLOGLEVEL)
   applicationUtilities.openFileLogger(executerLogLocation,executerLogFilename,
                                       executerLogLevel)
   applicationUtilities.daemonize()
   applicationUtilities.writePidFile(executerPidFile)

   executeJobs = ExecuteJobs(daemonsDirectory,daemonsConfigurationFile,
                             infosDirectory,infosConfigurationFile,
                             PREVIOUSSTATE,NEXTSTATE)
   executeJobs.process()

==> hubzero-submit-monitors_3.11.1-1+deb12.tar.gz: source/jobExecuter.py <==
#!/usr/bin/env python3
#
# @package      hubzero-submit-monitors
# @file         jobExecuter.py
# @copyright    Copyright (c) 2004-2020 The Regents of the University of California.
# @license      http://opensource.org/licenses/MIT MIT
#
# Copyright (c) 2004-2020 The Regents of the University of California.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# HUBzero is a registered trademark of The Regents of the University of California.
#
# ----------------------------------------------------------------------
#  jobExecuter.py
#
#  script which submits staged jobs
#
import sys
import os
import time
import logging

from hubzero.submit.ApplicationUtilities import ApplicationUtilities as ApplicationUtilities
from hubzero.submit.ExecuteJobs          import ExecuteJobs

EXECUTERLOGLEVEL         = "INFO"
EXECUTERSYSLOGLOCAL      = "LOCAL3"
EXECUTERSYSLOGIDENTIFIER = "SUBMITJOBEXE"

DAEMONSDIRECTORY         = os.path.join(os.sep,"etc","submit")
DAEMONSCONFIGURATIONFILE = 'daemons.conf'
INFOSDIRECTORY           = os.path.join(os.sep,"etc","submit")
INFOSCONFIGURATIONFILE   = 'infos.conf'

EXECUTERPIDFILE = os.path.join(os.sep,'var','run','submit','submit-jobexe.pid')

PREVIOUSSTATE = 'STAGEDIN'
NEXTSTATE     = 'EXECUTING'

if __name__ == '__main__':
   executerLogLevel         = os.getenv("EXECUTERLOGLEVEL",EXECUTERLOGLEVEL)
   executerSysLogLocal      = os.getenv("EXECUTERSYSLOGLOCAL",EXECUTERSYSLOGLOCAL)
   executerSysLogIdentifier = os.getenv("EXECUTERSYSLOGIDENTIFIER",EXECUTERSYSLOGIDENTIFIER)
   executerPidFile          = os.getenv("EXECUTERPIDFILE",EXECUTERPIDFILE)
   daemonsDirectory         = os.getenv("DAEMONSDIRECTORY",DAEMONSDIRECTORY)
   daemonsConfigurationFile = os.getenv("DAEMONSCONFIGURATIONFILE",DAEMONSCONFIGURATIONFILE)
   infosDirectory           = os.getenv("INFOSDIRECTORY",INFOSDIRECTORY)
   infosConfigurationFile   = os.getenv("INFOSCONFIGURATIONFILE",INFOSCONFIGURATIONFILE)

   applicationUtilities = ApplicationUtilities(EXECUTERLOGLEVEL,
                                               defaultSysLogLocal=EXECUTERSYSLOGLOCAL)
   applicationUtilities.openSysLogLogger(executerSysLogLocal,
                                         executerLogLevel,
                                         logIdentifier=executerSysLogIdentifier)
   applicationUtilities.daemonize()
   applicationUtilities.writePidFile(executerPidFile)

   executeJobs = ExecuteJobs(daemonsDirectory,daemonsConfigurationFile,
                             infosDirectory,infosConfigurationFile,
                             PREVIOUSSTATE,NEXTSTATE)
   executeJobs.process()
